You are viewing a plain text version of this content. The canonical link for it is here.
Posted to modperl-cvs@perl.apache.org by ge...@apache.org on 2005/03/08 02:58:55 UTC

svn commit: r156472 [3/4] - in perl/modperl/branches/apache2-rename-unstable/t: conf/ filter/TestFilter/ hooks/TestHooks/ htdocs/includes-registry/ htdocs/vhost/ lib/TestCommon/ preconnection/TestPreConnection/ protocol/TestProtocol/ response/TestAPI/ response/TestAPR/ response/TestApache/ response/TestCompat/ response/TestDirective/ response/TestError/ response/TestModperl/ response/TestModules/ response/TestPerl/ response/TestUser/ response/TestVhost/

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/server_util.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/server_util.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/show.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/show.pm Mon Mar  7 17:58:09 2005
@@ -6,8 +6,8 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::MPM ();
-use Apache::Const -compile => 'OK';
+use Apache2::MPM ();
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -16,11 +16,11 @@
 
     my $mpm = Apache::Test::config->{server}->{mpm};
 
-    ok t_cmp(Apache::MPM->show(),
+    ok t_cmp(Apache2::MPM->show(),
              qr!$mpm!i,
-             'Apache::MPM->show()');
+             'Apache2::MPM->show()');
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/slurp_filename.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/slurp_filename.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/slurp_filename.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/slurp_filename.pm Mon Mar  7 17:58:09 2005
@@ -9,10 +9,10 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::RequestUtil ();
+use Apache2::RequestUtil ();
 use ModPerl::Util;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 my $expected = <<EOI;
 English: Internet
@@ -54,7 +54,7 @@
         ok t_cmp($received, $expected, "slurp filename (perl) untainted");
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 sub slurp_filename_perl {

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/status.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/status.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/status.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/status.pm Mon Mar  7 17:58:09 2005
@@ -5,10 +5,10 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 my $body = "This is a response string";
 
@@ -27,7 +27,7 @@
         $r->status($code);
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/sub_request.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/sub_request.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/sub_request.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/sub_request.pm Mon Mar  7 17:58:09 2005
@@ -5,14 +5,14 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::SubRequest ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::SubRequest ();
 
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => qw(OK SERVER_ERROR);
+use Apache2::Const -compile => qw(OK SERVER_ERROR);
 
 my $uri = '/' . Apache::TestRequest::module2path(__PACKAGE__);
 
@@ -20,24 +20,24 @@
     my $r = shift;
 
     my $args = $r->args || '';
-    return Apache::SERVER_ERROR if $args eq 'subreq';
+    return Apache2::SERVER_ERROR if $args eq 'subreq';
 
     plan $r, tests => 4;
 
     my $subr = $r->lookup_uri("$uri?subreq");
-    ok $subr->isa('Apache::SubRequest');
+    ok $subr->isa('Apache2::SubRequest');
 
     ok t_cmp $subr->uri, $uri, "uri";
 
     my $rc = $subr->run;
-    ok $rc, Apache::SERVER_ERROR, "rc";
+    ok $rc, Apache2::SERVER_ERROR, "rc";
 
     # test an explicit DESTROY (which happens automatically on the
     # scope exit)
     undef $subr;
     ok 1;
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/uri.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/uri.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/uri.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/uri.pm Mon Mar  7 17:58:09 2005
@@ -9,11 +9,11 @@
 
 use APR::Pool ();
 use APR::URI ();
-use Apache::URI ();
-use Apache::RequestRec ();
-use Apache::RequestUtil ();
+use Apache2::URI ();
+use Apache2::RequestRec ();
+use Apache2::RequestUtil ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 my $location = '/' . Apache::TestRequest::module2path(__PACKAGE__);
 
@@ -141,7 +141,7 @@
         my $path     = "/foo/bar";
         my $query    = "query";
         my $fragment = "fragment";
-        my $newr = Apache::RequestRec->new($r->connection, $r->pool);
+        my $newr = Apache2::RequestRec->new($r->connection, $r->pool);
         my $url_string = "$path?$query#$fragment";
 
         # new request
@@ -176,12 +176,12 @@
         my @c = qw(one two three);
         my $url_string = join '%20', @c;
 
-        Apache::URI::unescape_url($url_string);
+        Apache2::URI::unescape_url($url_string);
 
         ok $url_string eq "@c";
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/base64.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/base64.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/base64.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/base64.pm Mon Mar  7 17:58:09 2005
@@ -4,7 +4,7 @@
 use warnings FATAL => 'all';
 
 use Apache::Test;
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use TestAPRlib::base64;
 
@@ -16,7 +16,7 @@
 
     TestAPRlib::base64::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/brigade.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/brigade.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/brigade.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/brigade.pm Mon Mar  7 17:58:09 2005
@@ -11,10 +11,10 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::RequestRec ();
+use Apache2::RequestRec ();
 use APR::Brigade ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
 
@@ -96,7 +96,7 @@
         ok t_cmp($data, "1112", "correct data");
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/bucket.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/bucket.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/bucket.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/bucket.pm Mon Mar  7 17:58:09 2005
@@ -11,10 +11,10 @@
 use APR::Brigade ();
 use APR::Bucket ();
 use APR::BucketType ();
-use Apache::Connection ();
-use Apache::RequestRec ();
+use Apache2::Connection ();
+use Apache2::RequestRec ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use TestAPRlib::bucket;
 
@@ -141,7 +141,7 @@
         ok 1;
     }
 
-    return Apache::OK;
+    return Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/date.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/date.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/date.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/date.pm Mon Mar  7 17:58:09 2005
@@ -7,7 +7,7 @@
 
 use Apache::Test;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use TestAPRlib::date;
 
@@ -19,7 +19,7 @@
 
     TestAPRlib::date::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/finfo.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/finfo.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/finfo.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/finfo.pm Mon Mar  7 17:58:09 2005
@@ -6,14 +6,14 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
 use TestAPRlib::finfo;
 
 use APR::Finfo ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 use APR::Const    -compile => qw(FINFO_NORM);
 
 sub handler {
@@ -34,7 +34,7 @@
 
     TestAPRlib::finfo::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/flatten.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/flatten.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/flatten.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/flatten.pm Mon Mar  7 17:58:09 2005
@@ -7,11 +7,11 @@
 use Apache::TestUtil;
 use TestCommon::Utils;
 
-use Apache::RequestRec ();
+use Apache2::RequestRec ();
 use APR::Bucket ();
 use APR::Brigade ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
 
@@ -93,7 +93,7 @@
         verify($len, 0, $data, 0);
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 # this sub runs 3 sub-tests with a false $check_content

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/ipsubnet.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/ipsubnet.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/ipsubnet.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/ipsubnet.pm Mon Mar  7 17:58:09 2005
@@ -6,13 +6,13 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Connection ();
-use Apache::RequestRec ();
+use Apache2::Connection ();
+use Apache2::RequestRec ();
 use APR::Pool ();
 use APR::IpSubnet ();
 use APR::SockAddr ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -80,7 +80,7 @@
         ok $ipsub->test($c->remote_addr);
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/os.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/os.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/os.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/os.pm Mon Mar  7 17:58:09 2005
@@ -6,17 +6,17 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::MPM ();
+use Apache2::MPM ();
 use APR::OS ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
 
     plan $r, tests => 1;
 
-    if (Apache::MPM->is_threaded) {
+    if (Apache2::MPM->is_threaded) {
         my $tid = APR::OS::current_thread_id();
         ok t_cmp($tid, $tid, "current thread id: $tid / pid: $$");
     }
@@ -24,7 +24,7 @@
         ok t_cmp($$, $$, "current process id");
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/perlio.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/perlio.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/perlio.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/perlio.pm Mon Mar  7 17:58:09 2005
@@ -13,7 +13,7 @@
 use Fcntl ();
 use File::Spec::Functions qw(catfile);
 
-use Apache::Const -compile => qw(OK CRLF);
+use Apache2::Const -compile => qw(OK CRLF);
 
 #XXX: APR::LARGE_FILES_CONFLICT constant?
 #XXX: you can set to zero if largefile support is not enabled in Perl
@@ -21,9 +21,9 @@
 
 # apr_file_dup has a bug on win32,
 # should be fixed in apr 0.9.4 / httpd-2.0.48
-require Apache::Build;
+require Apache2::Build;
 use constant APR_WIN32_FILE_DUP_BUG => 
-    Apache::Build::WIN32() && !have_min_apache_version('2.0.48');
+    Apache2::Build::WIN32() && !have_min_apache_version('2.0.48');
 
 sub handler {
     my $r = shift;
@@ -273,7 +273,7 @@
             $text = <$rfh>;
         }
         close $rfh;
-        ok t_cmp(count_chars($text, Apache::CRLF),
+        ok t_cmp(count_chars($text, Apache2::CRLF),
                  $count,
                  'testing for presence of \015\012');
         ok t_cmp(count_chars($text, "\n"),
@@ -282,7 +282,7 @@
 
         open $wfh, ">:APR", $scratch, $r->pool
             or die "Cannot open $scratch for writing: $!";
-        print $wfh 'a' . ((('a' x 14) . Apache::CRLF) x $count);
+        print $wfh 'a' . ((('a' x 14) . Apache2::CRLF) x $count);
         close $wfh;
         open $rfh, "<:APR", $scratch, $r->pool
             or die "Cannot open $scratch for reading: $!";
@@ -291,7 +291,7 @@
             $text = <$rfh>;
         }
         close $rfh;
-        ok t_cmp(count_chars($text, Apache::CRLF),
+        ok t_cmp(count_chars($text, Apache2::CRLF),
                  $count,
                  'testing for presence of \015\012');
         ok t_cmp(count_chars($text, "\n"),
@@ -304,7 +304,7 @@
             $text = <$rfh>;
         }
         close $rfh;
-        ok t_cmp(count_chars($text, Apache::CRLF),
+        ok t_cmp(count_chars($text, Apache2::CRLF),
                  0,
                  'testing for presence of \015\012');
         ok t_cmp(count_chars($text, "\n"),
@@ -340,7 +340,7 @@
 
     # cleanup: t_mkdir will remove the whole tree including the file
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 sub count_chars {

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/pool.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/pool.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/pool.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/pool.pm Mon Mar  7 17:58:09 2005
@@ -7,11 +7,11 @@
 use Apache::TestUtil;
 use Apache::TestTrace;
 
-use Apache::RequestRec ();
+use Apache2::RequestRec ();
 use APR::Pool ();
 use APR::Table ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use TestAPRlib::pool;
 
@@ -63,7 +63,7 @@
 
     TestAPRlib::pool::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 sub set_cleanup {

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/pool_lifetime.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/pool_lifetime.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/pool_lifetime.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/pool_lifetime.pm Mon Mar  7 17:58:09 2005
@@ -6,10 +6,10 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 my $pool;
 
@@ -19,7 +19,7 @@
     $r->print("Pong");
     $pool = $r->pool;
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/sockaddr.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/sockaddr.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/sockaddr.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/sockaddr.pm Mon Mar  7 17:58:09 2005
@@ -8,11 +8,11 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Connection ();
-use Apache::RequestRec ();
+use Apache2::Connection ();
+use Apache2::RequestRec ();
 use APR::SockAddr ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -30,7 +30,7 @@
     ok t_cmp($local->port,  $ENV{SERVER_PORT}, "local port");
     ok t_cmp($remote->port, $ENV{REMOTE_PORT}, "remote port");
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/socket.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/socket.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/socket.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/socket.pm Mon Mar  7 17:58:09 2005
@@ -8,11 +8,11 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::RequestRec ();
-use Apache::Connection ();
+use Apache2::RequestRec ();
+use Apache2::Connection ();
 use APR::Socket ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 use APR::Const -compile => 'EMISMATCH';
 
 sub handler {
@@ -40,7 +40,7 @@
     $socket->timeout_set($orig_val);
     ok t_cmp($socket->timeout_get(), $orig_val, "timeout_get()");
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/string.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/string.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/string.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/string.pm Mon Mar  7 17:58:09 2005
@@ -5,7 +5,7 @@
 
 use Apache::Test;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 require TestAPRlib::string;
 
@@ -17,7 +17,7 @@
 
     TestAPRlib::string::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/table.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/table.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/table.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/table.pm Mon Mar  7 17:58:09 2005
@@ -6,7 +6,7 @@
 use warnings FATAL => 'all';
 
 use Apache::Test;
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use TestAPRlib::table;
 
@@ -18,7 +18,7 @@
 
     TestAPRlib::table::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/threadmutex.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/threadmutex.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/threadmutex.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/threadmutex.pm Mon Mar  7 17:58:09 2005
@@ -6,7 +6,7 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use TestAPRlib::threadmutex;
 
@@ -18,7 +18,7 @@
 
     TestAPRlib::threadmutex::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/uri.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/uri.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/uri.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/uri.pm Mon Mar  7 17:58:09 2005
@@ -7,7 +7,7 @@
 
 use Apache::Test;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use TestAPRlib::uri;
 
@@ -19,7 +19,7 @@
 
     TestAPRlib::uri::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/util.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/util.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/util.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/util.pm Mon Mar  7 17:58:09 2005
@@ -7,7 +7,7 @@
 
 use Apache::Test;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use TestAPRlib::util;
 
@@ -19,7 +19,7 @@
 
     TestAPRlib::util::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/uuid.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/uuid.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/uuid.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPR/uuid.pm Mon Mar  7 17:58:09 2005
@@ -7,7 +7,7 @@
 
 use TestAPRlib::uuid;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -16,7 +16,7 @@
 
     TestAPRlib::uuid::test();
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/cgihandler.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/cgihandler.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/cgihandler.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/cgihandler.pm Mon Mar  7 17:58:09 2005
@@ -3,10 +3,10 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
+use Apache2::RequestRec ();
 use APR::Table ();
 
-use Apache::Const -compile => qw(OK M_POST);
+use Apache2::Const -compile => qw(OK M_POST);
 
 #test the 1.x style perl-script handler
 
@@ -15,7 +15,7 @@
 
     $ENV{FOO} = 2;
 
-    if ($r->method_number == Apache::M_POST) {
+    if ($r->method_number == Apache2::M_POST) {
         my $cl = $r->headers_in->get('content-length');
         my $buff;
 #XXX: working around a bug in ithreads Perl
@@ -35,7 +35,7 @@
         print "ok $foo\n";
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/conftree.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/conftree.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/conftree.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/conftree.pm Mon Mar  7 17:58:09 2005
@@ -7,9 +7,9 @@
 use Apache::TestUtil;
 use Apache::TestConfig ();
 
-use Apache::Directive ();
+use Apache2::Directive ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -26,7 +26,7 @@
 
     ok $vars;
 
-    my $tree = Apache::Directive::conftree();
+    my $tree = Apache2::Directive::conftree();
 
     ok $tree;
 
@@ -66,7 +66,7 @@
 
     traverse_tree ( \&test_node );
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 sub test_node {
@@ -82,7 +82,7 @@
 
 sub traverse_tree {
     my ($sub, $data) = @_;
-    my $node = Apache::Directive::conftree();
+    my $node = Apache2::Directive::conftree();
     while ($node) {
         $sub->($data, $node);
         if (my $kid = $node->first_child) {

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/content_length_header.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/content_length_header.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/content_length_header.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/content_length_header.pm Mon Mar  7 17:58:09 2005
@@ -5,11 +5,11 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::Response ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::Response ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 my $body = "This is a response string";
 
@@ -35,7 +35,7 @@
         }
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/discard_rbody.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/discard_rbody.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/discard_rbody.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/discard_rbody.pm Mon Mar  7 17:58:09 2005
@@ -6,16 +6,16 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::Connection ();
-use Apache::Filter ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::Connection ();
+use Apache2::Filter ();
 use APR::Brigade ();
 use APR::Error ();
 
 use TestCommon::Utils ();
 
-use Apache::Const -compile => qw(OK MODE_READBYTES);
+use Apache2::Const -compile => qw(OK MODE_READBYTES);
 use APR::Const    -compile => qw(SUCCESS BLOCK_READ);
 
 use constant IOBUFSIZE => 8192;
@@ -35,7 +35,7 @@
         my $filters = $r->input_filters();
         my $ba = $r->connection->bucket_alloc;
         my $bb = APR::Brigade->new($r->pool, $ba);
-        $filters->get_brigade($bb, Apache::MODE_READBYTES,
+        $filters->get_brigade($bb, Apache2::MODE_READBYTES,
                               APR::BLOCK_READ, IOBUFSIZE);
     }
     elsif ($test eq 'all') {
@@ -47,11 +47,11 @@
     # now get rid of the rest of the input data should work, no matter
     # how little or how much of the body was read
     my $rc = $r->discard_request_body;
-    die APR::Error::strerror($rc) unless $rc == Apache::OK;
+    die APR::Error::strerror($rc) unless $rc == Apache2::OK;
 
     $r->print($test);
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/post.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/post.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/post.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/post.pm Mon Mar  7 17:58:09 2005
@@ -3,12 +3,12 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
 use TestCommon::Utils ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -18,7 +18,7 @@
 
     $r->puts(join ':', length($data), $data);
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/read.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/read.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/read.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/read.pm Mon Mar  7 17:58:09 2005
@@ -3,12 +3,12 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
 use TestCommon::Utils;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use constant BUFSIZ => 512; #small for testing
 
@@ -40,7 +40,7 @@
 
     $r->puts($buffer);
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/read2.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/read2.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/read2.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/read2.pm Mon Mar  7 17:58:09 2005
@@ -5,14 +5,14 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 use APR::Table ();
 
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 my $expected = "foobar";
 
@@ -33,7 +33,7 @@
              $expected,
              "reading into an autovivified hash entry");
 
-    Apache::OK;
+    Apache2::OK;
 }
 1;
 

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/scanhdrs.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/scanhdrs.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/scanhdrs.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/scanhdrs.pm Mon Mar  7 17:58:09 2005
@@ -5,9 +5,9 @@
 
 use Apache::Test;
 
-use Apache::compat ();
+use Apache2::compat ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -21,7 +21,7 @@
 
     print "ok 1\n";
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/scanhdrs2.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/scanhdrs2.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/scanhdrs2.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/scanhdrs2.pm Mon Mar  7 17:58:09 2005
@@ -5,7 +5,7 @@
 
 use Apache::Test;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -14,7 +14,7 @@
 
     print "Location: $location\n\n";
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/send_cgi_header.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/send_cgi_header.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/send_cgi_header.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/send_cgi_header.pm Mon Mar  7 17:58:09 2005
@@ -3,9 +3,9 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::Response ();
+use Apache2::Response ();
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 sub handler {
     my $r = shift;
@@ -23,7 +23,7 @@
     # don't tell anybody
     $r->send_cgi_header($response);
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/subprocess.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/subprocess.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/subprocess.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/subprocess.pm Mon Mar  7 17:58:09 2005
@@ -5,17 +5,17 @@
 
 use Apache::Test;
 use Apache::TestUtil;
-use Apache::Build;
+use Apache2::Build;
 
 use File::Spec::Functions qw(catfile catdir);
 use IO::Select ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use Config;
 use constant PERLIO_5_8_IS_ENABLED => $Config{useperlio} && $] >= 5.007;
 
-my $perl = Apache::Build->build_config()->perl_config('perlpath');
+my $perl = Apache2::Build->build_config()->perl_config('perlpath');
 
 my %scripts = (
      argv   => 'print STDOUT "@ARGV";',
@@ -43,7 +43,7 @@
     my $cfg = Apache::Test::config();
     my $vars = $cfg->{vars};
 
-    plan $r, tests => 5, need qw(APR::PerlIO Apache::SubProcess);
+    plan $r, tests => 5, need qw(APR::PerlIO Apache2::SubProcess);
 
     my $target_dir = catfile $vars->{documentroot}, "util";
 
@@ -115,24 +115,24 @@
 
 # these are wannabe's
 #    ok t_cmp(
-#             Apache::SubProcess::spawn_proc_sub($r, $sub, \@args),
-#             Apache::SUCCESS,
+#             Apache2::SubProcess::spawn_proc_sub($r, $sub, \@args),
+#             Apache2::SUCCESS,
 #             "spawn a subprocess and run a subroutine in it"
 #            );
 
 #    ok t_cmp(
-#             Apache::SubProcess::spawn_thread_prog($r, $command, \@argv),
-#             Apache::SUCCESS,
+#             Apache2::SubProcess::spawn_thread_prog($r, $command, \@argv),
+#             Apache2::SUCCESS,
 #             "spawn thread and run a program in it"
 #            );
 
 #     ok t_cmp(
-#             Apache::SubProcess::spawn_thread_sub($r, $sub, \@args),
-#             Apache::SUCCESS,
+#             Apache2::SubProcess::spawn_thread_sub($r, $sub, \@args),
+#             Apache2::SUCCESS,
 #             "spawn thread and run a subroutine in it"
 #            );
 
-   Apache::OK;
+   Apache2::OK;
 }
 
 

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/util.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/util.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/util.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/util.pm Mon Mar  7 17:58:09 2005
@@ -1,6 +1,6 @@
 package TestApache::util;
 
-# Apache::Util tests
+# Apache2::Util tests
 
 use strict;
 use warnings FATAL => 'all';
@@ -18,15 +18,15 @@
 # regex matching (LC_CTYPE) of strftime-like (LC_TIME) strings
 use locale;
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::Util ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::Util ();
 use APR::Date ();
 
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 # those are passed via PerlPassEnv
 my $locale = $ENV{LC_TIME} || '';
@@ -45,22 +45,22 @@
         my $fmt = "%a, %d %b %Y %H:%M:%S %Z";
         my $fmtdate;
 
-        $fmtdate = Apache::Util::ht_time($r->pool);
+        $fmtdate = Apache2::Util::ht_time($r->pool);
         time_cmp($fmtdate, $time,
-                 'Apache::Util::ht_time($pool)', 0);
+                 'Apache2::Util::ht_time($pool)', 0);
 
-        $fmtdate = Apache::Util::ht_time($r->pool, $time);
+        $fmtdate = Apache2::Util::ht_time($r->pool, $time);
         time_cmp($fmtdate, $time,
-                 'Apache::Util::ht_time($pool, $time)', 1);
+                 'Apache2::Util::ht_time($pool, $time)', 1);
 
-        $fmtdate = Apache::Util::ht_time($r->pool, $time, $fmt);
+        $fmtdate = Apache2::Util::ht_time($r->pool, $time, $fmt);
         time_cmp($fmtdate, $time,
-                 'Apache::Util::ht_time($pool, $time, $fmt)', 1);
+                 'Apache2::Util::ht_time($pool, $time, $fmt)', 1);
 
         my $gmt = 0;
-        $fmtdate = Apache::Util::ht_time($r->pool, $time, $fmt, $gmt);
+        $fmtdate = Apache2::Util::ht_time($r->pool, $time, $fmt, $gmt);
         time_cmp($fmtdate, $time,
-                 'Apache::Util::ht_time($pool, $time, $fmt, $gmt)', 0);
+                 'Apache2::Util::ht_time($pool, $time, $fmt, $gmt)', 0);
     }
 
     # escape_path
@@ -70,30 +70,30 @@
         $uri = "a 'long' file?.html";
         ($expected = $uri) =~ s/([\s?;])/sprintf "%%%x", ord $1/ge;
 
-        $received = Apache::Util::escape_path($uri, $r->pool);
+        $received = Apache2::Util::escape_path($uri, $r->pool);
         ok t_cmp $received, $expected,
-            "Apache::Util::escape_path / partial=1 / default";
+            "Apache2::Util::escape_path / partial=1 / default";
 
-        $received = Apache::Util::escape_path($uri, $r->pool, 1);
+        $received = Apache2::Util::escape_path($uri, $r->pool, 1);
         ok t_cmp $received, $expected,
-            "Apache::Util::escape_path / partial=1 / explicit";
+            "Apache2::Util::escape_path / partial=1 / explicit";
 
-        $received = Apache::Util::escape_path($uri, $r->pool, 0);
+        $received = Apache2::Util::escape_path($uri, $r->pool, 0);
         ok t_cmp $received, $expected,
-            "Apache::Util::escape_path / partial=0";
+            "Apache2::Util::escape_path / partial=0";
 
         $uri = "a 'long' file?.html:";
         ($expected = $uri) =~ s/([\s?;])/sprintf "%%%x", ord $1/ge;
         # XXX: why does it prepend ./ only if it sees : or :/?
         $expected = "./$expected";
 
-        $received = Apache::Util::escape_path($uri, $r->pool, 0);
+        $received = Apache2::Util::escape_path($uri, $r->pool, 0);
         ok t_cmp $received, $expected,
-            "Apache::Util::escape_path / partial=0 / ./ prefix ";
+            "Apache2::Util::escape_path / partial=0 / ./ prefix ";
 
     }
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 my $fmtdate_re = qr/^\w+, \d\d \w+ \d\d\d\d \d\d:\d\d:\d\d/;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/write.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/write.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/write.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestApache/write.pm Mon Mar  7 17:58:09 2005
@@ -3,10 +3,10 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 use constant BUFSIZ => 512; #small for testing
 
@@ -24,7 +24,7 @@
     $ok = "not ok 2\n";
     $r->write($ok, 5, 4);
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache.pm Mon Mar  7 17:58:09 2005
@@ -11,8 +11,8 @@
 use Apache::Test;
 
 use ModPerl::Util ();
-use Apache::compat ();
-use Apache::Constants qw(DIR_MAGIC_TYPE :common :response);
+use Apache2::compat ();
+use Apache2::Constants qw(DIR_MAGIC_TYPE :common :response);
 
 use File::Spec::Functions qw(catfile canonpath);
 
@@ -28,13 +28,13 @@
     ok t_cmp(ref($fh), 'GLOB', "Apache->gensym");
 
     ok t_cmp(Apache->module('mod_perl.c'), 1,
-             "Apache::module('mod_perl.c')");
+             "Apache2::module('mod_perl.c')");
     ok t_cmp(Apache->module('mod_ne_exists.c'), 0,
-             "Apache::module('mod_ne_exists.c')");
+             "Apache2::module('mod_ne_exists.c')");
 
 
     ok t_cmp(Apache->define('MODPERL2'),
-             Apache::ServerUtil::exists_config_define('MODPERL2'),
+             Apache2::ServerUtil::exists_config_define('MODPERL2'),
              'Apache->define');
 
     ok t_cmp($r->current_callback,
@@ -42,7 +42,7 @@
              'inside PerlResponseHandler');
 
     t_server_log_error_is_expected();
-    Apache::log_error("Apache::log_error test ok");
+    Apache2::log_error("Apache::log_error test ok");
     ok 1;
 
     t_server_log_warn_is_expected();
@@ -50,15 +50,15 @@
     ok 1;
 
     t_server_log_warn_is_expected();
-    Apache::warn('Apache::warn ok');
+    Apache2::warn('Apache::warn ok');
     ok 1;
 
     t_server_log_warn_is_expected();
-    Apache::Server->warn('Apache::Server->warn ok');
+    Apache2::Server->warn('Apache::Server->warn ok');
     ok 1;
 
     t_server_log_warn_is_expected();
-    Apache::Server::warn('Apache::Server::warn ok');
+    Apache2::Server::warn('Apache::Server::warn ok');
     ok 1;
 
     # explicitly imported
@@ -85,7 +85,7 @@
     # (Apache||$r)->server_root_relative
     {
         my $server_root = Apache::Test::config()->{vars}->{serverroot};
-        ok t_filepath_cmp(canonpath($Apache::Server::CWD),
+        ok t_filepath_cmp(canonpath($Apache2::Server::CWD),
                           canonpath($server_root),
                           '$server_root');
 
@@ -105,7 +105,7 @@
                           canonpath($server_root),
                           'Apache->server_root_relative()');
 
-        my $path = catfile(Apache::ServerUtil::server_root, 'logs');
+        my $path = catfile(Apache2::ServerUtil::server_root, 'logs');
         ok t_filepath_cmp(canonpath(Apache->server_root_relative($path)),
                           canonpath($path),
                           "Apache->server_root_relative('$path')");
@@ -115,8 +115,8 @@
              '/foo bar baz',
              'Apache->unescape_url_info');
 
-    ok t_cmp $Apache::Server::Starting,   0, '$Apache::Server::Starting';
-    ok t_cmp $Apache::Server::ReStarting, 1, '$Apache::Server::ReStarting';
+    ok t_cmp $Apache2::Server::Starting,   0, '$Apache::Server::Starting';
+    ok t_cmp $Apache2::Server::ReStarting, 1, '$Apache::Server::ReStarting';
 
     OK;
 }

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_file.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_file.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/conn_authen.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/conn_authen.pm Mon Mar  7 17:58:09 2005
@@ -12,8 +12,8 @@
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::compat ();
-use Apache::Constants qw(OK REMOTE_HOST);
+use Apache2::compat ();
+use Apache2::Constants qw(OK REMOTE_HOST);
 
 sub handler {
 
@@ -27,7 +27,7 @@
     # get_basic_auth_pw populates $r->user and $r->ap_auth_type
     my($rc, $sent_pw) = $r->get_basic_auth_pw;
 
-    return $rc if $rc != Apache::OK;
+    return $rc if $rc != Apache2::OK;
 
     $req_auth_type = $r->connection->auth_type || '';
 

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/conn_rec.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/conn_rec.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/conn_rec.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/conn_rec.pm Mon Mar  7 17:58:09 2005
@@ -6,11 +6,11 @@
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::compat ();
+use Apache2::compat ();
 
 use Socket qw(sockaddr_in inet_ntoa);
 
-use Apache::Constants qw(OK);
+use Apache2::Constants qw(OK);
 
 sub handler {
 
@@ -20,16 +20,16 @@
 
      plan $r, tests => 4;
 
-     Apache::compat::override_mp2_api('Apache::Connection::local_addr');
+     Apache2::compat::override_mp2_api('Apache::Connection::local_addr');
      my ($local_port, $local_addr) = sockaddr_in($c->local_addr);
-     Apache::compat::restore_mp2_api('Apache::Connection::local_addr');
+     Apache2::compat::restore_mp2_api('Apache::Connection::local_addr');
      t_debug inet_ntoa($local_addr) . " :$local_port";
      ok $local_port;
      ok inet_ntoa($local_addr);
 
-     Apache::compat::override_mp2_api('Apache::Connection::remote_addr');
+     Apache2::compat::override_mp2_api('Apache::Connection::remote_addr');
      my ($remote_port, $remote_addr) = sockaddr_in($c->remote_addr);
-     Apache::compat::restore_mp2_api('Apache::Connection::remote_addr');
+     Apache2::compat::restore_mp2_api('Apache::Connection::remote_addr');
      t_debug inet_ntoa($remote_addr) . " :$remote_port";
      ok $remote_port;
      ok inet_ntoa($remote_addr);

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/request.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/request.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/request.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/request.pm Mon Mar  7 17:58:09 2005
@@ -14,8 +14,8 @@
 
 use File::Spec::Functions qw(catfile);
 
-use Apache::compat ();
-use Apache::Constants qw(OK REMOTE_HOST);
+use Apache2::compat ();
+use Apache2::Constants qw(OK REMOTE_HOST);
 
 sub handler {
     my $r = shift;
@@ -78,7 +78,7 @@
 
     # $r->filename
     {
-        Apache::compat::override_mp2_api('Apache::RequestRec::filename');
+        Apache2::compat::override_mp2_api('Apache::RequestRec::filename');
         my $orig = $r->filename;
         my $new  = catfile Apache::Test::vars("serverroot"),
             "conf", "httpd.conf";
@@ -94,12 +94,12 @@
 
         # restore the real 2.0 filename() method, now that we are done
         # with the compat one
-        Apache::compat::restore_mp2_api('Apache::RequestRec::filename');
+        Apache2::compat::restore_mp2_api('Apache::RequestRec::filename');
     }
 
     # $r->notes
     {
-        Apache::compat::override_mp2_api('Apache::RequestRec::notes');
+        Apache2::compat::override_mp2_api('Apache::RequestRec::notes');
 
         my $key = 'notes-test';
         # get/set scalar context
@@ -127,12 +127,12 @@
 
         # restore the real 2.0 notes() method, now that we are done
         # with the compat one
-        Apache::compat::restore_mp2_api('Apache::RequestRec::notes');
+        Apache2::compat::restore_mp2_api('Apache::RequestRec::notes');
     }
 
     # get_remote_host()
     ok $r->get_remote_host() || 1;
-    ok $r->get_remote_host(Apache::REMOTE_HOST) || 1;
+    ok $r->get_remote_host(Apache2::REMOTE_HOST) || 1;
 
     # post_connection()
     $r->post_connection(sub { OK });

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/request_body.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/request_body.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/request_body.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/request_body.pm Mon Mar  7 17:58:09 2005
@@ -8,8 +8,8 @@
 use Apache::TestUtil;
 use Apache::Test ();
 
-use Apache::compat ();
-use Apache::Constants qw(OK M_POST DECLINED);
+use Apache2::compat ();
+use Apache2::Constants qw(OK M_POST DECLINED);
 
 use subs qw(ok debug);
 my $gr;
@@ -28,7 +28,7 @@
         %data = $r->content;
     }
     else {
-        %data = $r->Apache::args;
+        %data = $r->Apache2::args;
     }
 
     return DECLINED unless exists $data{test};

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/send_fd.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/send_fd.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/send_fd.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/send_fd.pm Mon Mar  7 17:58:09 2005
@@ -3,23 +3,23 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::compat ();
-use Apache::RequestRec ();
+use Apache2::compat ();
+use Apache2::RequestRec ();
 
-use Apache::Const -compile => ':common';
+use Apache2::Const -compile => ':common';
 
 sub handler {
     my $r = shift;
 
     my $file = $r->args || __FILE__;
 
-    open my $fh, $file or return Apache::NOT_FOUND;
+    open my $fh, $file or return Apache2::NOT_FOUND;
 
     my $bytes = $r->send_fd($fh);
 
-    return Apache::SERVER_ERROR unless $bytes == -s $file;
+    return Apache2::SERVER_ERROR unless $bytes == -s $file;
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/cmdparms.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/cmdparms.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/cmdparms.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/cmdparms.pm Mon Mar  7 17:58:09 2005
@@ -3,13 +3,13 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::CmdParms ();
-use base qw(Apache::Module);
+use Apache2::CmdParms ();
+use base qw(Apache2::Module);
 
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => qw(
+use Apache2::Const -compile => qw(
     ACCESS_CONF
     M_GET
     M_POST
@@ -35,7 +35,7 @@
     },
 );
 
-Apache::Module::add(__PACKAGE__, \@directives);
+Apache2::Module::add(__PACKAGE__, \@directives);
 
 my @methods = qw(cmd context directive info override path
                  pool server temp_pool);
@@ -47,7 +47,7 @@
         $srv_cfg->{$args}{$method} = $parms->$method();
     }
     $srv_cfg->{$args}{check_ctx} = 
-        $parms->check_cmd_context(Apache::NOT_IN_LOCATION);
+        $parms->check_cmd_context(Apache2::NOT_IN_LOCATION);
 
     $srv_cfg->{$args}{limited} = $parms->method_is_limited('GET');    
 }
@@ -61,12 +61,12 @@
     plan $r, tests => 9 + ( 7 * keys(%$srv_cfg) );
 
     foreach my $cfg (values %$srv_cfg) {
-        ok t_cmp(ref($cfg->{cmd}), 'Apache::Command', 'cmd');
-        ok t_cmp(ref($cfg->{context}), 'Apache::ConfVector', 'context');
-        ok t_cmp(ref($cfg->{directive}), 'Apache::Directive', 'directive');
+        ok t_cmp(ref($cfg->{cmd}), 'Apache2::Command', 'cmd');
+        ok t_cmp(ref($cfg->{context}), 'Apache2::ConfVector', 'context');
+        ok t_cmp(ref($cfg->{directive}), 'Apache2::Directive', 'directive');
         ok t_cmp(ref($cfg->{pool}), 'APR::Pool', 'pool');
         ok t_cmp(ref($cfg->{temp_pool}), 'APR::Pool', 'temp_pool');
-        ok t_cmp(ref($cfg->{server}), 'Apache::ServerRec', 'server');
+        ok t_cmp(ref($cfg->{server}), 'Apache2::ServerRec', 'server');
         ok t_cmp($cfg->{info}, 'cmd_data', 'cmd_data');
     }
 
@@ -74,10 +74,10 @@
     {
         my $vhost = $srv_cfg->{Vhost};
 
-        my $wanted = Apache::RSRC_CONF   |
-                     Apache::OR_INDEXES  |
-                     Apache::OR_FILEINFO |
-                     Apache::OR_OPTIONS;
+        my $wanted = Apache2::RSRC_CONF   |
+                     Apache2::OR_INDEXES  |
+                     Apache2::OR_FILEINFO |
+                     Apache2::OR_OPTIONS;
         my $masked = $vhost->{override} & $wanted;
 
         ok t_cmp($masked, $wanted, 'override bitmask');
@@ -90,12 +90,12 @@
     {
         my $loc = $srv_cfg->{Location};
 
-        my $wanted = Apache::ACCESS_CONF |
-                     Apache::OR_INDEXES  |
-                     Apache::OR_AUTHCFG  |
-                     Apache::OR_FILEINFO |
-                     Apache::OR_OPTIONS  |
-                     Apache::OR_LIMIT;
+        my $wanted = Apache2::ACCESS_CONF |
+                     Apache2::OR_INDEXES  |
+                     Apache2::OR_AUTHCFG  |
+                     Apache2::OR_FILEINFO |
+                     Apache2::OR_OPTIONS  |
+                     Apache2::OR_LIMIT;
         my $masked = $loc->{override} & $wanted;
 
         ok t_cmp($masked, $wanted, 'override bitmask');
@@ -111,7 +111,7 @@
         ok !$limit->{limited};
     }
 
-    return Apache::OK;
+    return Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/env.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/env.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/env.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/env.pm Mon Mar  7 17:58:09 2005
@@ -6,10 +6,10 @@
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::RequestRec ();
+use Apache2::RequestRec ();
 use APR::Table ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -52,7 +52,7 @@
              'test.host.name',
              '$r->subprocess_env PerlPassEnv');
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 sub env_get {

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perldo.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perldo.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perldo.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perldo.pm Mon Mar  7 17:58:09 2005
@@ -5,8 +5,8 @@
 
 use Apache::Test;
 use Apache::TestUtil;
-use Apache::Const -compile => 'OK';
-use Apache::PerlSections;
+use Apache2::Const -compile => 'OK';
+use Apache2::PerlSections;
 
 sub handler {
     my $r = shift;
@@ -43,15 +43,15 @@
 
     ok t_cmp($TestDirective::perl::Included, 1, "Include");
 
-    my $dump = Apache::PerlSections->dump;
-    ok t_cmp($dump, qr/__END__/, "Apache::PerlSections->dump");
+    my $dump = Apache2::PerlSections->dump;
+    ok t_cmp($dump, qr/__END__/, "Apache2::PerlSections->dump");
 
     eval "package TestDirective::perldo::test;\nno strict;\n$dump";
     ok t_cmp($@, "", "PerlSections dump syntax check");
 
     ok t_cmp($TestDirective::perldo::test::Include, qr/perlsection.conf/);
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule.pm Mon Mar  7 17:58:09 2005
@@ -7,18 +7,18 @@
 use Apache::TestUtil;
 use Apache::TestTrace;
 
-use Apache::Const -compile => qw(OK OR_ALL RSRC_CONF TAKE1 TAKE23);
+use Apache2::Const -compile => qw(OK OR_ALL RSRC_CONF TAKE1 TAKE23);
 
-use Apache::CmdParms ();
-use Apache::Module ();
+use Apache2::CmdParms ();
+use Apache2::Module ();
 
 my @directives = (
     {
      name => 'MyTest',
      func => __PACKAGE__ . '::MyTest',
-     req_override => Apache::RSRC_CONF,
+     req_override => Apache2::RSRC_CONF,
 #     req_override => 'RSRC_CONF', #test 1.x compat for strings
-#     args_how => Apache::TAKE23,
+#     args_how => Apache2::TAKE23,
      args_how => 'TAKE23', #test 1.x compat for strings
      errmsg => 'A test',
     },
@@ -28,11 +28,11 @@
     },
     {
      name => 'ServerTest',
-     req_override => Apache::RSRC_CONF,
+     req_override => Apache2::RSRC_CONF,
     }
 );
 
-Apache::Module::add(__PACKAGE__, \@directives);
+Apache2::Module::add(__PACKAGE__, \@directives);
 
 sub DIR_CREATE {
     my($class, $parms) = @_;
@@ -93,7 +93,7 @@
 
 sub get_config {
     my($self, $s) = (shift, shift);
-    Apache::Module::get_config($self, $s, @_);
+    Apache2::Module::get_config($self, $s, @_);
 }
 
 sub handler : method {
@@ -132,7 +132,7 @@
 
     ok t_cmp($srv_cfg->{ServerTest}, 'per-server');
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule2.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule2.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule2.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule2.pm Mon Mar  7 17:58:09 2005
@@ -6,22 +6,22 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::Const -compile => qw(OK OR_ALL ITERATE);
+use Apache2::Const -compile => qw(OK OR_ALL ITERATE);
 
-use Apache::CmdParms ();
-use Apache::Module ();
+use Apache2::CmdParms ();
+use Apache2::Module ();
 
 my @directives = (
     {
      name         => 'MyMergeTest',
      func         => __PACKAGE__ . '::MyMergeTest',
-     req_override => Apache::OR_ALL,
-     args_how     => Apache::ITERATE,
+     req_override => Apache2::OR_ALL,
+     args_how     => Apache2::ITERATE,
      errmsg       => 'Values that get merged',
     },
 );
 
-Apache::Module::add(__PACKAGE__, \@directives);
+Apache2::Module::add(__PACKAGE__, \@directives);
 
 sub merge {
     my($base, $add) = @_;
@@ -72,7 +72,7 @@
 
 sub get_config {
     my($self, $s) = (shift, shift);
-    Apache::Module::get_config($self, $s, @_);
+    Apache2::Module::get_config($self, $s, @_);
 }
 
 sub handler : method {
@@ -91,7 +91,7 @@
         $r->print("dir: @{ $dir_cfg->{MyMergeTest}||[] }");
     }
 
-    return Apache::OK;
+    return Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule3.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule3.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule3.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule3.pm Mon Mar  7 17:58:09 2005
@@ -9,11 +9,11 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::CmdParms ();
-use Apache::Module ();
-use Apache::ServerUtil ();
+use Apache2::CmdParms ();
+use Apache2::Module ();
+use Apache2::ServerUtil ();
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 
 my @directives = (
@@ -23,7 +23,7 @@
     { name => 'MyOverride' },
 );
 
-Apache::Module::add(__PACKAGE__, \@directives);
+Apache2::Module::add(__PACKAGE__, \@directives);
 
 sub MyPlus     { set_val('MyPlus',     @_) }
 sub MyAppend   { set_val('MyAppend',   @_) }
@@ -37,7 +37,7 @@
     my($key, $self, $parms, $arg) = @_;
     $self->{$key} = $arg;
     unless ($parms->path) {
-        my $srv_cfg = Apache::Module::get_config($self, $parms->server);
+        my $srv_cfg = Apache2::Module::get_config($self, $parms->server);
         $srv_cfg->{$key} = $arg;
     }
 }
@@ -46,7 +46,7 @@
     my($key, $self, $parms, $arg) = @_;
     push @{ $self->{$key} }, $arg;
     unless ($parms->path) {
-        my $srv_cfg = Apache::Module::get_config($self, $parms->server);
+        my $srv_cfg = Apache2::Module::get_config($self, $parms->server);
         push @{ $srv_cfg->{$key} }, $arg;
     }
 }
@@ -80,16 +80,16 @@
 ### response handler ###
 
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::ServerRec ();
-use Apache::ServerUtil ();
-use Apache::Module ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::ServerRec ();
+use Apache2::ServerUtil ();
+use Apache2::Module ();
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 sub get_config {
-    Apache::Module::get_config(__PACKAGE__, @_);
+    Apache2::Module::get_config(__PACKAGE__, @_);
 }
 
 sub handler {
@@ -125,7 +125,7 @@
         }
     }
 
-    return Apache::OK;
+    return Apache2::OK;
 }
 
 

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule4.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule4.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule4.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule4.pm Mon Mar  7 17:58:09 2005
@@ -18,42 +18,42 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::CmdParms ();
-use Apache::Module ();
-use Apache::ServerUtil ();
+use Apache2::CmdParms ();
+use Apache2::Module ();
+use Apache2::ServerUtil ();
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 use constant KEY => "MyTest4";
 
 my @directives = ({ name => +KEY },);
 
-Apache::Module::add(__PACKAGE__, \@directives);
+Apache2::Module::add(__PACKAGE__, \@directives);
 
 sub MyTest4 {
     my($self, $parms, $arg) = @_;
     $self->{+KEY} = $arg;
 
     unless ($parms->path) {
-        my $srv_cfg = Apache::Module::get_config($self, $parms->server);
+        my $srv_cfg = Apache2::Module::get_config($self, $parms->server);
         $srv_cfg->{+KEY} = $arg;
     }
 }
 
 ### response handler ###
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::ServerRec ();
-use Apache::ServerUtil ();
-use Apache::Module ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::ServerRec ();
+use Apache2::ServerUtil ();
+use Apache2::Module ();
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 sub get_config {
-    Apache::Module::get_config(__PACKAGE__, @_);
+    Apache2::Module::get_config(__PACKAGE__, @_);
 }
 
 sub handler {
@@ -74,7 +74,7 @@
 
     ok t_cmp($srv_cfg->{+KEY}, "Vhost", "Section");
 
-    return Apache::OK;
+    return Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule5.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule5.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule5.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule5.pm Mon Mar  7 17:58:09 2005
@@ -16,41 +16,41 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::CmdParms ();
-use Apache::Module ();
-use Apache::ServerUtil ();
+use Apache2::CmdParms ();
+use Apache2::Module ();
+use Apache2::ServerUtil ();
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 use constant KEY => "MyTest5";
 
 my @directives = ({ name => +KEY },);
 
-Apache::Module::add(__PACKAGE__, \@directives);
+Apache2::Module::add(__PACKAGE__, \@directives);
 
 sub MyTest5 {
     my($self, $parms, $arg) = @_;
     $self->{+KEY} = $arg;
     unless ($parms->path) {
-        my $srv_cfg = Apache::Module::get_config($self, $parms->server);
+        my $srv_cfg = Apache2::Module::get_config($self, $parms->server);
         $srv_cfg->{+KEY} = $arg;
     }
 }
 
 ### response handler ###
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::ServerRec ();
-use Apache::ServerUtil ();
-use Apache::Module ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::ServerRec ();
+use Apache2::ServerUtil ();
+use Apache2::Module ();
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 sub get_config {
-    Apache::Module::get_config(__PACKAGE__, @_);
+    Apache2::Module::get_config(__PACKAGE__, @_);
 }
 
 sub handler {
@@ -71,7 +71,7 @@
 
     ok t_cmp($srv_cfg->{+KEY}, "Vhost", "Section");
 
-    return Apache::OK;
+    return Apache2::OK;
 }
 
 

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule6.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule6.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule6.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlloadmodule6.pm Mon Mar  7 17:58:09 2005
@@ -6,41 +6,41 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Apache::CmdParms ();
-use Apache::Module ();
-use Apache::ServerUtil ();
+use Apache2::CmdParms ();
+use Apache2::Module ();
+use Apache2::ServerUtil ();
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 use constant KEY => "MyTest6";
 
 my @directives = ({ name => +KEY },);
 
-Apache::Module::add(__PACKAGE__, \@directives);
+Apache2::Module::add(__PACKAGE__, \@directives);
 
 sub MyTest6 {
     my($self, $parms, $arg) = @_;
     $self->{+KEY} = $arg;
     unless ($parms->path) {
-        my $srv_cfg = Apache::Module::get_config($self, $parms->server);
+        my $srv_cfg = Apache2::Module::get_config($self, $parms->server);
         $srv_cfg->{+KEY} = $arg;
     }
 }
 
 ### response handler ###
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
-use Apache::ServerRec ();
-use Apache::ServerUtil ();
-use Apache::Module ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
+use Apache2::ServerRec ();
+use Apache2::ServerUtil ();
+use Apache2::Module ();
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::Const -compile => qw(OK);
+use Apache2::Const -compile => qw(OK);
 
 sub get_config {
-    Apache::Module::get_config(__PACKAGE__, @_);
+    Apache2::Module::get_config(__PACKAGE__, @_);
 }
 
 sub handler {
@@ -61,7 +61,7 @@
 
     ok t_cmp($srv_cfg->{+KEY}, "Vhost", "Section");
 
-    return Apache::OK;
+    return Apache2::OK;
 }
 
 1;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlmodule.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlmodule.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlmodule.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlmodule.pm Mon Mar  7 17:58:09 2005
@@ -9,11 +9,11 @@
 
 use Apache::Test ();
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 use File::Spec::Functions qw(catfile);
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -21,7 +21,7 @@
     $r->content_type('text/plain');
     $r->puts($ApacheTest::PerlModuleTest::MAGIC || '');
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 sub APACHE_TEST_CONFIGURE {

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlrequire.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlrequire.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlrequire.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/perlrequire.pm Mon Mar  7 17:58:09 2005
@@ -11,11 +11,11 @@
 
 use Apache::Test ();
 
-use Apache::RequestRec ();
-use Apache::RequestIO ();
+use Apache2::RequestRec ();
+use Apache2::RequestIO ();
 use File::Spec::Functions qw(catfile);
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -23,7 +23,7 @@
     $r->content_type('text/plain');
     $r->puts($ApacheTest::PerlRequireTest::MAGIC || '');
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 my %require_tests = 

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/pod.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/pod.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/pod.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestDirective/pod.pm Mon Mar  7 17:58:09 2005
@@ -5,7 +5,7 @@
 
 use Apache::Test;
 use Apache::TestUtil;
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 sub handler {
     my $r = shift;
@@ -19,7 +19,7 @@
     #XXX: How to test that __END__ works proprely without cloberring all the other tests?
     ok t_cmp '__END__', '__END__';
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 1;
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/server_util.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/server_util.pm Mon Mar  7 17:58:09 2005
@@ -7,18 +7,18 @@
 use Apache::TestUtil;
 use File::Spec::Functions qw(canonpath catfile);
 
-use Apache::RequestRec ();
-use Apache::ServerRec ();
-use Apache::ServerUtil ();
-use Apache::Process ();
+use Apache2::RequestRec ();
+use Apache2::ServerRec ();
+use Apache2::ServerUtil ();
+use Apache2::Process ();
 
 use APR::Pool ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 
 my $serverroot = Apache::Test::config()->{vars}->{serverroot};
 
-our @ISA = qw(Apache::RequestRec);
+our @ISA = qw(Apache2::RequestRec);
 
 sub new {
     my $class = shift;
@@ -39,26 +39,26 @@
         ok t_cmp(scalar(@handlers), scalar(@expected), "get_handlers");
     }
 
-    t_debug('Apache::ServerUtil::exists_config_define');
-    ok Apache::ServerUtil::exists_config_define('MODPERL2');
-    ok ! Apache::ServerUtil::exists_config_define('FOO');
+    t_debug('Apache2::ServerUtil::exists_config_define');
+    ok Apache2::ServerUtil::exists_config_define('MODPERL2');
+    ok ! Apache2::ServerUtil::exists_config_define('FOO');
 
     t_debug('registering method FOO');
     ok $r->server->method_register('FOO');
 
     server_root_relative_tests($r);
 
-    eval { Apache::ServerUtil::server_shutdown_cleanup_register(
-        sub { Apache::OK });
+    eval { Apache2::ServerUtil::server_shutdown_cleanup_register(
+        sub { Apache2::OK });
        };
     my $sub = "server_shutdown_cleanup_register";
     ok t_cmp $@, qr/Can't run '$sub' after server startup/,
         "can't register server_shutdown cleanup after server startup";
 
     # on start we get 1, and immediate restart gives 2
-    ok t_cmp Apache::ServerUtil::restart_count, 2, "restart count";
+    ok t_cmp Apache2::ServerUtil::restart_count, 2, "restart count";
 
-    Apache::OK;
+    Apache2::OK;
 }
 
 
@@ -76,8 +76,8 @@
     );
 
     # syntax - an object or pool is required
-    t_debug("Apache::ServerUtil::server_root_relative() died");
-    eval { my $dir = Apache::ServerUtil::server_root_relative() };
+    t_debug("Apache2::ServerUtil::server_root_relative() died");
+    eval { my $dir = Apache2::ServerUtil::server_root_relative() };
     t_debug("\$\@: $@");
     ok $@;
 
@@ -86,42 +86,42 @@
         # pool whose life is longer than of $r, but it doesn't matter
         # for the test
         ok t_filepath_cmp(
-            canonpath(Apache::ServerUtil::server_root_relative($pools{$p},
+            canonpath(Apache2::ServerUtil::server_root_relative($pools{$p},
                                                                'conf')),
             catfile($serverroot, 'conf'),
-            "Apache::ServerUtil:::server_root_relative($p, 'conf')");
+            "Apache2::ServerUtil:::server_root_relative($p, 'conf')");
     }
 
     # syntax - unrecognized objects don't segfault
     {
-        my $obj = bless {}, 'Apache::Foo';
-        eval { Apache::ServerUtil::server_root_relative($obj, 'conf') };
+        my $obj = bless {}, 'Apache2::Foo';
+        eval { Apache2::ServerUtil::server_root_relative($obj, 'conf') };
 
         ok t_cmp($@,
                  qr/p is not of type APR::Pool/,
-                 "Apache::ServerUtil::server_root_relative(\$obj, 'conf')");
+                 "Apache2::ServerUtil::server_root_relative(\$obj, 'conf')");
     }
 
     # no file argument gives ServerRoot
     {
         my $server_root_relative = 
-            Apache::ServerUtil::server_root_relative($r->pool);
+            Apache2::ServerUtil::server_root_relative($r->pool);
 
         ok t_filepath_cmp(canonpath($server_root_relative),
                           canonpath($serverroot),
                           'server_root_relative($pool)');
 
-        # Apache::ServerUtil::server_root is also the ServerRoot constant
-        ok t_filepath_cmp(canonpath(Apache::ServerUtil::server_root),
+        # Apache2::ServerUtil::server_root is also the ServerRoot constant
+        ok t_filepath_cmp(canonpath(Apache2::ServerUtil::server_root),
                           canonpath($server_root_relative),
-                          'Apache::ServerUtil::server_root');
+                          'Apache2::ServerUtil::server_root');
 
     }
 
     {
         # absolute paths should resolve to themselves
-        my $dir1 = Apache::ServerUtil::server_root_relative($r->pool, 'logs');
-        my $dir2 = Apache::ServerUtil::server_root_relative($r->pool, $dir1);
+        my $dir1 = Apache2::ServerUtil::server_root_relative($r->pool, 'logs');
+        my $dir2 = Apache2::ServerUtil::server_root_relative($r->pool, $dir1);
 
         ok t_filepath_cmp($dir1, $dir2, "absolute path");
     }

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/show.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestAPI/show.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_file.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_file.pm Mon Mar  7 17:58:09 2005
@@ -1,6 +1,6 @@
 package TestCompat::apache_file;
 
 # Apache::File compat layer tests
 
 # these tests are all run and validated on the server side.
 
@@ -10,8 +10,8 @@
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::compat ();
-use Apache::Constants qw(OK);
+use Apache2::compat ();
+use Apache2::Constants qw(OK);
 
 sub handler {
     my $r = shift;
@@ -23,11 +23,11 @@
     my $cfg = Apache::Test::config();
     my $vars = $cfg->{vars};
 
-    require Apache::File;
+    require Apache2::File;
     my $file = $vars->{t_conf_file};
 
-    t_debug "new Apache::File file object";
-    ok my $fh = Apache::File->new;
+    t_debug "new Apache2::File file object";
+    ok my $fh = Apache2::File->new;
 
     t_debug "open itself";
     if ($fh->open($file)) {
@@ -51,7 +51,7 @@
     ok !$fh->open("$file.nochance");
 
     t_debug "new+open";
-    if (my $fh = Apache::File->new($file)) {
+    if (my $fh = Apache2::File->new($file)) {
         ok 1;
         $fh->close;
     }
@@ -60,10 +60,10 @@
     }
 
     t_debug "new+open non-exists";
-    ok !Apache::File->new("$file.yeahright");
+    ok !Apache2::File->new("$file.yeahright");
 
     # tmpfile
-    my ($tmpfile, $tmpfh) = Apache::File->tmpfile;
+    my ($tmpfile, $tmpfh) = Apache2::File->tmpfile;
 
     t_debug "open tmpfile fh";
     ok $tmpfh;
@@ -77,11 +77,11 @@
     ok t_cmp(<$tmpfh>, $write, "write/read from tmpfile");
 
     ok t_cmp($r->discard_request_body,
-             Apache::OK,
+             Apache2::OK,
              "\$r->discard_request_body");
 
     ok t_cmp($r->meets_conditions,
-             Apache::OK,
+             Apache2::OK,
              "\$r->meets_conditions");
 
     my $csize = 10;
@@ -1,6 +1,6 @@
 package TestCompat::apache_file;
 
-# Apache::File compat layer tests
+# Apache2::File compat layer tests
 
 # these tests are all run and validated on the server side.

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_module.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_module.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_module.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_module.pm Mon Mar  7 17:58:09 2005
@@ -1,6 +1,6 @@
 package TestCompat::apache_module;
 
 # Apache::Module compat layer tests
 
 use strict;
 use warnings FATAL => 'all';
@@ -8,7 +8,7 @@
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::compat ();
+use Apache2::compat ();
 use Apache::Constants qw(OK);
 
 my @directives = (
@@ -17,11 +17,11 @@
     },
 );
 
-Apache::Module::add(__PACKAGE__, \@directives);
+Apache2::Module::add(__PACKAGE__, \@directives);
 
 sub TestCompatApacheModuleParms {
     my($self, $parms, $args) = @_;
-    my $config = Apache::Module->get_config($self, $parms->server);
+    my $config = Apache2::Module->get_config($self, $parms->server);
     $config->{data} = $args;
 }
 
@@ -30,10 +30,10 @@
 
     plan $r, tests => 2;
 
-    my $top_module = Apache::Module->top_module();
-    ok t_cmp (ref($top_module), 'Apache::Module');
+    my $top_module = Apache2::Module->top_module();
+    ok t_cmp (ref($top_module), 'Apache2::Module');
 
-    my $config = Apache::Module->get_config($self, $r->server);
+    my $config = Apache2::Module->get_config($self, $r->server);
     ok t_cmp ($config->{data}, 'Test');
 
     OK;
@@ -1,6 +1,6 @@
 package TestCompat::apache_module;
 
-# Apache::Module compat layer tests
+# Apache2::Module compat layer tests
 
 use strict;

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_table.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_table.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_table.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_table.pm Mon Mar  7 17:58:09 2005
@@ -1,6 +1,6 @@
 package TestCompat::apache_table;
 
 # Apache::Table compat layer tests
 
 # these tests are all run and validated on the server side.
 
@@ -10,8 +10,8 @@
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::compat ();
-use Apache::Constants qw(OK);
+use Apache2::compat ();
+use Apache2::Constants qw(OK);
 
 sub handler {
     my $r = shift;
@@ -20,10 +20,10 @@
 
     $r->send_http_header('text/plain');
 
-    my $t = Apache::Table->new($r);
+    my $t = Apache2::Table->new($r);
     my $t_class = ref $t;
 
-    ok t_cmp($t_class, 'APR::Table', "Apache::Table->new");
+    ok t_cmp($t_class, 'APR::Table', "Apache2::Table->new");
 
     ok t_cmp($r->is_main, !$r->main,
              '$r->is_main');
@@ -1,6 +1,6 @@
 package TestCompat::apache_table;
 
-# Apache::Table compat layer tests
+# Apache2::Table compat layer tests
 
 # these tests are all run and validated on the server side.

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_uri.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_uri.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_uri.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_uri.pm Mon Mar  7 17:58:09 2005
@@ -1,6 +1,6 @@
 package TestCompat::apache_uri;
 
 # Apache::Util compat layer tests
 
 # these tests are all run and validated on the server side.
 
@@ -10,8 +10,8 @@
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::compat ();
-use Apache::Constants qw(OK);
+use Apache2::compat ();
+use Apache2::Constants qw(OK);
 
 sub handler {
     my $r = shift;
@@ -24,9 +24,9 @@
                          query fragment port);
         my $test_uri = 'http://foo:bar@perl.apache.org:80/docs?args#frag';
 
         # Apache::URI->parse internally returns an object blessed into
         # APR::URI and all the methods are called on that object
-        for my $uri ($r->parsed_uri, Apache::URI->parse($r, $test_uri)) {
+        for my $uri ($r->parsed_uri, Apache2::URI->parse($r, $test_uri)) {
             t_debug("URI=" . $uri->unparse);
             no strict 'refs';
             # just check that methods are call-able, the actual
@@ -40,7 +40,7 @@
     }
 
     {
-        Apache::compat::override_mp2_api('APR::URI::unparse');
+        Apache2::compat::override_mp2_api('APR::URI::unparse');
         # test the segfault in apr < 0.9.2 (fixed on mod_perl side)
         # passing only the /path
         my $parsed = $r->parsed_uri;
@@ -49,7 +49,7 @@
         $parsed->port($r->get_server_port);
         #$parsed->scheme('http'); # compat defaults to 'http' like apache-1.3 did
         ok t_cmp($parsed->unparse, $r->construct_url);
-        Apache::compat::restore_mp2_api('APR::URI::unparse');
+        Apache2::compat::restore_mp2_api('APR::URI::unparse');
     }
 
     OK;
@@ -1,6 +1,6 @@
 package TestCompat::apache_uri;
 
-# Apache::Util compat layer tests
+# Apache2::Util compat layer tests
 
 # these tests are all run and validated on the server side.
@@ -24,9 +24,9 @@
         my $test_uri = 'http://foo:bar@perl.apache.org:80/docs?args#frag';
 
-        # Apache::URI->parse internally returns an object blessed into
+        # Apache2::URI->parse internally returns an object blessed into
         # APR::URI and all the methods are called on that object

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_util.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_util.pm?view=diff&r1=156471&r2=156472
==============================================================================
--- perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_util.pm (original)
+++ perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/apache_util.pm Mon Mar  7 17:58:09 2005
@@ -1,6 +1,6 @@
 package TestCompat::apache_util;
 
 # Apache::Util compat layer tests
 
 # these tests are all run and validated on the server side.
 
@@ -10,8 +10,8 @@
 use Apache::TestUtil;
 use Apache::Test;
 
-use Apache::compat ();
-use Apache::Constants qw(OK);
+use Apache2::compat ();
+use Apache2::Constants qw(OK);
 
 my %string_size = (
     '-1'            => "    -",
@@ -43,7 +43,7 @@
     # size_string()
     {
         while (my($k, $v) = each %string_size) {
-            ok t_cmp($v, Apache::Util::size_string($k));
+            ok t_cmp($v, Apache2::Util::size_string($k));
         }
     }
 
@@ -52,46 +52,46 @@
     (my $esc_uri = $uri) =~ s/ /\%20/g;
     my $uri2 = $uri;
 
-    $uri  = Apache::Util::escape_uri($uri);
-    $uri2 = Apache::Util::escape_path($uri2, $r->pool);
+    $uri  = Apache2::Util::escape_uri($uri);
+    $uri2 = Apache2::Util::escape_path($uri2, $r->pool);
 
-    ok t_cmp($uri, $esc_uri, "Apache::Util::escape_uri");
-    ok t_cmp($uri2, $esc_uri, "Apache::Util::escape_path");
+    ok t_cmp($uri, $esc_uri, "Apache2::Util::escape_uri");
+    ok t_cmp($uri2, $esc_uri, "Apache2::Util::escape_path");
 
-    ok t_cmp(Apache::Util::unescape_uri($uri2),
-             Apache::URI::unescape_url($uri),
-             "Apache::URI::unescape_uri vs Apache::Util::unescape_uri");
+    ok t_cmp(Apache2::Util::unescape_uri($uri2),
+             Apache2::URI::unescape_url($uri),
+             "Apache2::URI::unescape_uri vs Apache::Util::unescape_uri");
 
     ok t_cmp($uri2,
              $uri,
-             "Apache::URI::unescape_uri vs Apache::Util::unescape_uri");
+             "Apache2::URI::unescape_uri vs Apache::Util::unescape_uri");
 
     # escape_html()
     my $html = '<p>"hi"&foo</p>';
     my $esc_html = '&lt;p&gt;&quot;hi&quot;&amp;foo&lt;/p&gt;';
 
-    ok t_cmp(Apache::Util::escape_html($html), $esc_html,
-             "Apache::Util::escape_html");
+    ok t_cmp(Apache2::Util::escape_html($html), $esc_html,
+             "Apache2::Util::escape_html");
 
 
     # ht_time(), parsedate()
     my $time = time;
-    Apache::compat::override_mp2_api('Apache::Util::ht_time');
-    my $fmtdate = Apache::Util::ht_time($time);
-    Apache::compat::restore_mp2_api('Apache::Util::ht_time');
+    Apache2::compat::override_mp2_api('Apache::Util::ht_time');
+    my $fmtdate = Apache2::Util::ht_time($time);
+    Apache2::compat::restore_mp2_api('Apache::Util::ht_time');
 
-    ok t_cmp($fmtdate, $fmtdate, "Apache::Util::ht_time");
+    ok t_cmp($fmtdate, $fmtdate, "Apache2::Util::ht_time");
 
     if ($parse_time_ok) {
-        my $ptime = Apache::Util::parsedate($fmtdate);
-        ok t_cmp($ptime, $time, "Apache::Util::parsedate");
+        my $ptime = Apache2::Util::parsedate($fmtdate);
+        ok t_cmp($ptime, $time, "Apache2::Util::parsedate");
     }
 
     if ($crypt_ok) {
         # not all platforms support C-level crypt
         my $hash = "aX9eP53k4DGfU";
-        ok t_cmp(Apache::Util::validate_password("dougm", $hash), 1);
-        ok t_cmp(Apache::Util::validate_password("mguod", $hash), 0);
+        ok t_cmp(Apache2::Util::validate_password("dougm", $hash), 1);
+        ok t_cmp(Apache2::Util::validate_password("mguod", $hash), 0);
     }
 
     OK;
@@ -1,6 +1,6 @@
 package TestCompat::apache_util;
 
-# Apache::Util compat layer tests
+# Apache2::Util compat layer tests
 
 # these tests are all run and validated on the server side.

Modified: perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/conn_authen.pm
URL: http://svn.apache.org/viewcvs/perl/modperl/branches/apache2-rename-unstable/t/response/TestCompat/conn_authen.pm?view=diff&r1=156471&r2=156472
==============================================================================